import { eq } from 'drizzle-orm';
import { users } from '#db/schema';

/**
 * 用户服务模块
 * @param {object} fastify - Fastify实例
 */
export default async function userService(fastify) {
    const { db } = fastify;

    return {
        /**
         * 根据ID获取用户
         * @param {number} userId - 用户ID
         * @returns {Promise<object>} 用户对象
         */
        async getUserById(userId) {
            return db
                .select()
                .from(users)
                .where(eq(users.id, userId))
                .limit(1)
                .then(res => res[0]);
        },

        /**
         * 创建新用户
         * @param {object} userData - 用户数据
         * @returns {Promise<object>} 创建的用户记录
         */
        async createUser(userData) {
            return db.insert(users).values(userData).returning();
        },
    };
}
